==> brmo-stufbg204-1.5.1-sources.jar: nl/egem/stuf/stuf0204/FoutBericht.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.egem.nl/StUF/StUF0204}stuurgegevens"/>
 *         &lt;element name="body">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="code" type="{http://www.egem.nl/StUF/StUF0204}FoutCode"/>
 *                   &lt;element name="plek" type="{http://www.egem.nl/StUF/StUF0204}FoutPlek"/>
 *                   &lt;element name="omschrijving" type="{http://www.egem.nl/StUF/StUF0204}FoutOmschrijving"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "stuurgegevens",
    "body"
})
@XmlRootElement(name = "foutBericht")
public class FoutBericht {

    @XmlElement(required = true)
    protected Stuurgegevens stuurgegevens;
    @XmlElement(required = true)
    protected FoutBericht.Body body;

    /**
     * Gets the value of the stuurgegevens property.
     * 
     * @return
     *     possible object is
     *     {@link Stuurgegevens }
     *     
     */
    public Stuurgegevens getStuurgegevens() {
        return stuurgegevens;
    }

    /**
     * Sets the value of the stuurgegevens property.
     * 
     * @param value
     *     allowed object is
     *     {@link Stuurgegevens }
     *     
     */
    public void setStuurgegevens(Stuurgegevens value) {
        this.stuurgegevens = value;
    }

    /**
     * Gets the value of the body property.
     * 
     * @return
     *     possible object is
     *     {@link FoutBericht.Body }
     *     
     */
    public FoutBericht.Body getBody() {
        return body;
    }

    /**
     * Sets the value of the body property.
     * 
     * @param value
     *     allowed object is
     *     {@link FoutBericht.Body }
     *     
     */
    public void setBody(FoutBericht.Body value) {
        this.body = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="code" type="{http://www.egem.nl/StUF/StUF0204}FoutCode"/>
     *         &lt;element name="plek" type="{http://www.egem.nl/StUF/StUF0204}FoutPlek"/>
     *         &lt;element name="omschrijving" type="{http://www.egem.nl/StUF/StUF0204}FoutOmschrijving"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "code",
        "plek",
        "omschrijving"
    })
    public static class Body {

        @XmlElement(required = true)
        protected String code;
        @XmlElement(required = true)
        protected FoutPlek plek;
        @XmlElement(required = true)
        protected String omschrijving;

        /**
         * Gets the value of the code property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCode() {
            return code;
        }

        /**
         * Sets the value of the code property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCode(String value) {
            this.code = value;
        }

        /**
         * Gets the value of the plek property.
         * 
         * @return
         *     possible object is
         *     {@link FoutPlek }
         *     
         */
        public FoutPlek getPlek() {
            return plek;
        }

        /**
         * Sets the value of the plek property.
         * 
         * @param value
         *     allowed object is
         *     {@link FoutPlek }
         *     
         */
        public void setPlek(FoutPlek value) {
            this.plek = value;
        }

        /**
         * Gets the value of the omschrijving property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getOmschrijving() {
            return omschrijving;
        }

        /**
         * Sets the value of the omschrijving property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setOmschrijving(String value) {
            this.omschrijving = value;
        }

    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/stuf0204/FoutBericht.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.egem.nl/StUF/StUF0204}stuurgegevens"/&gt;
 *         &lt;element name="body"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="code" type="{http://www.egem.nl/StUF/StUF0204}FoutCode"/&gt;
 *                   &lt;element name="plek" type="{http://www.egem.nl/StUF/StUF0204}FoutPlek"/&gt;
 *                   &lt;element name="omschrijving" type="{http://www.egem.nl/StUF/StUF0204}FoutOmschrijving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "stuurgegevens",
    "body"
})
@XmlRootElement(name = "foutBericht")
public class FoutBericht {

    @XmlElement(required = true)
    protected Stuurgegevens stuurgegevens;
    @XmlElement(required = true)
    protected FoutBericht.Body body;

    /**
     * Gets the value of the stuurgegevens property.
     * 
     * @return
     *     possible object is
     *     {@link Stuurgegevens }
     *     
     */
    public Stuurgegevens getStuurgegevens() {
        return stuurgegevens;
    }

    /**
     * Sets the value of the stuurgegevens property.
     * 
     * @param value
     *     allowed object is
     *     {@link Stuurgegevens }
     *     
     */
    public void setStuurgegevens(Stuurgegevens value) {
        this.stuurgegevens = value;
    }

    /**
     * Gets the value of the body property.
     * 
     * @return
     *     possible object is
     *     {@link FoutBericht.Body }
     *     
     */
    public FoutBericht.Body getBody() {
        return body;
    }

    /**
     * Sets the value of the body property.
     * 
     * @param value
     *     allowed object is
     *     {@link FoutBericht.Body }
     *     
     */
    public void setBody(FoutBericht.Body value) {
        this.body = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="code" type="{http://www.egem.nl/StUF/StUF0204}FoutCode"/&gt;
     *         &lt;element name="plek" type="{http://www.egem.nl/StUF/StUF0204}FoutPlek"/&gt;
     *         &lt;element name="omschrijving" type="{http://www.egem.nl/StUF/StUF0204}FoutOmschrijving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "code",
        "plek",
        "omschrijving"
    })
    public static class Body {

        @XmlElement(required = true)
        protected String code;
        @XmlElement(required = true)
        @XmlSchemaType(name = "string")
        protected FoutPlek plek;
        @XmlElement(required = true)
        protected String omschrijving;

        /**
         * Gets the value of the code property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCode() {
            return code;
        }

        /**
         * Sets the value of the code property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCode(String value) {
            this.code = value;
        }

        /**
         * Gets the value of the plek property.
         * 
         * @return
         *     possible object is
         *     {@link FoutPlek }
         *     
         */
        public FoutPlek getPlek() {
            return plek;
        }

        /**
         * Sets the value of the plek property.
         * 
         * @param value
         *     allowed object is
         *     {@link FoutPlek }
         *     
         */
        public void setPlek(FoutPlek value) {
            this.plek = value;
        }

        /**
         * Gets the value of the omschrijving property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getOmschrijving() {
            return omschrijving;
        }

        /**
         * Sets the value of the omschrijving property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setOmschrijving(String value) {
            this.omschrijving = value;
        }

    }

}
